@@ -557,19 +557,17 @@ function whp_ClientArea(array $params) {
         
         $username = $params['username'];
         
-        // Get user information and usage statistics
+        // Get user information only (no server statistics for clients)
         $userResponse = whp_api_call($serverdata, 'GET', 'users.php?action=info&username=' . urlencode($username));
-        $statsResponse = whp_api_call($serverdata, 'GET', 'system.php?action=stats');
         
         $userInfo = $userResponse['status'] === 'success' ? $userResponse['data'] : null;
-        $serverStats = $statsResponse['status'] === 'success' ? $statsResponse['data'] : null;
         
         return array(
             'templatefile' => 'overview',
             'vars' => array(
                 'user_info' => $userInfo,
-                'server_stats' => $serverStats,
                 'username' => $username,
+                'serviceid' => $params['serviceid'],
             ),
         );
         
